AssetGeneratorHelper class abstract

Constructors

AssetGeneratorHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateAllInOne(List<String> assetEntries, AssetConfig config) Future<void>
Generate a single aggregated file: assets.gen.dart
generateSeparate(List<String> assetEntries, AssetConfig config) Future<void>
Generate separate files per group + a master aggregator file (assets.gen.dart)
parseAssetsFromPubspec() Future<List<String>>