AssetConfig class
Constructors
-
AssetConfig({required bool allInOne, required List<
String> includePaths, required Directory outputDirectory, String preClass = "App", String postClass = ""}) -
AssetConfig.fromArgs(List<
String> args) -
factory
Properties
- allInOne → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includePaths
→ List<
String> -
final
- outputDirectory → Directory
-
final
- postClass → String
-
final
- preClass → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
printHelp(
) → void